package com.example.aida.popups

import android.media.MediaPlayer
import androidx.compose.foundation.background
import androidx.compose.foundation.layout.*
import androidx.compose.foundation.shape.RoundedCornerShape
import androidx.compose.material3.*
import androidx.compose.runtime.*
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import androidx.compose.ui.draw.clip
import androidx.compose.ui.graphics.Color
import androidx.compose.ui.platform.LocalContext
import androidx.compose.ui.unit.dp
import androidx.compose.ui.window.Dialog
import com.example.aida.R

import com.example.aida.ui.composables.sequenceTabComposables.moveActionColor
import com.example.aida.ui.composables.sequenceTabComposables.specialActionColor

@Composable
fun PopupSounds(
    onDismiss: () -> Unit,
    onSave: (String) -> Unit
) {
    val context = LocalContext.current
    var selectedSound by remember { mutableStateOf<String?>(null) }
    var isPlayingSound by remember { mutableStateOf(false) }

    Dialog(
        onDismissRequest = onDismiss,
    ) {
        // Wraps the sound selection content.
        Surface(
            modifier = Modifier
                .fillMaxWidth()
                .wrapContentHeight(),
            shape = RoundedCornerShape(20.dp),
            shadowElevation = 8.dp,
            tonalElevation = 2.dp,
        ) {
            Box(
                modifier = Modifier
                    .background(moveActionColor)
                    .padding(20.dp)
                    .clip(RoundedCornerShape(20.dp)),
                contentAlignment = Alignment.Center
            ){
                Column(
                    modifier = Modifier
                        .background(Color.White)
                        .padding(16.dp),
                    horizontalAlignment = Alignment.CenterHorizontally
                ) {
                    Text(
                        text = "Select a Sound",
                        style = MaterialTheme.typography.titleLarge,
                        modifier = Modifier.padding(top = 8.dp, bottom = 8.dp)
                    )

                    // Displays the available sounds as SoundButton items.
                    robotSounds.forEach { (name, sound) ->
                        SoundButton(
                            label = name,
                            isSelected = selectedSound == name,
                            onClick = {
                                if (!isPlayingSound) {
                                    println("Selected sound: $name, resId: $sound")
                                    val mediaPlayer = MediaPlayer.create(context, sound)
                                    mediaPlayer.start()
                                    isPlayingSound = true
                                    mediaPlayer.setOnCompletionListener {
                                        isPlayingSound = false
                                    }
                                    selectedSound = name
                                } else {
                                    println("A sound is already playing, please wait.")
                                }
                            }
                        )
                    }

                    Spacer(modifier = Modifier.height(16.dp))

                    Row(
                        horizontalArrangement = Arrangement.SpaceBetween,
                        modifier = Modifier.fillMaxWidth()
                    ) {
                        // Cancel button that closes the popup without saving.
                        Button(
                            onClick = onDismiss,
                            colors = ButtonDefaults.buttonColors(
                                containerColor = cancelButtonColor
                            )
                        ) {
                            Text("Cancel")
                        }

                        // Save button that saves the selected sound and closes the popup, enabled only if a sound is selected.
                        Button(
                            modifier = Modifier,
                            colors = ButtonDefaults.buttonColors(saveButtonColor),
                            onClick = {
                                selectedSound?.let { onSave(it) }
                                onDismiss()
                            },
                            enabled = selectedSound != null
                        ) {
                            Text("Save")
                        }
                    }
                }
            }
        }
    }
}

@Composable
fun SoundButton(
    label: String,
    isSelected: Boolean,
    onClick: () -> Unit
) {
    // Creates a button with a background color based on selection state.
    Button(
        onClick = onClick,
        colors = ButtonDefaults.buttonColors(
            containerColor = if (isSelected) specialActionColor else moveActionColor
        ),
        modifier = Modifier
            .fillMaxWidth(0.9f)
            .padding(vertical = 4.dp)
    ) {
        Text(label)
    }
}

