package com.example.aida.popups

import android.app.Activity.RESULT_OK
import android.content.Intent
import android.speech.RecognizerIntent
import android.widget.Toast
import androidx.activity.compose.rememberLauncherForActivityResult
import androidx.activity.result.contract.ActivityResultContracts
import androidx.compose.foundation.layout.*
import androidx.compose.foundation.text.BasicTextField
import androidx.compose.material3.*
import androidx.compose.runtime.*
import androidx.compose.ui.Modifier
import androidx.compose.ui.text.TextStyle
import androidx.compose.ui.unit.dp
import androidx.compose.ui.unit.sp
import androidx.compose.ui.platform.LocalContext
import java.util.*
import androidx.compose.foundation.border


@Composable
fun SpeechToTextComponent() {
    val context = LocalContext.current
    var speechText by remember { mutableStateOf("") }
    var inputText by remember { mutableStateOf("") }

    // Remembering the launcher for speech-to-text intent
    val speechLauncher = rememberLauncherForActivityResult(
        contract = ActivityResultContracts.StartActivityForResult()
    ) { result ->
        if (result.resultCode == RESULT_OK && result.data != null) {
            val res = result.data?.getStringArrayListExtra(RecognizerIntent.EXTRA_RESULTS)
            speechText = res?.get(0).orEmpty()
        } else {
            Toast.makeText(context, "Failed to recognize speech", Toast.LENGTH_SHORT).show()
        }
    }

    // Function to launch the speech-to-text intent
    fun launchSpeechRecognizer() {
        val intent = Intent(RecognizerIntent.ACTION_RECOGNIZE_SPEECH).apply {
            putExtra(RecognizerIntent.EXTRA_LANGUAGE, Locale.getDefault())
            putExtra(RecognizerIntent.EXTRA_PROMPT, "Speak to text")
        }
        try {
            speechLauncher.launch(intent)
        } catch (e: Exception) {
            Toast.makeText(context, e.message.orEmpty(), Toast.LENGTH_SHORT).show()
        }
    }

    // UI Components
    Column(
        modifier = Modifier
            .fillMaxSize()
            .padding(16.dp),
        verticalArrangement = Arrangement.spacedBy(16.dp)
    ) {
        BasicTextField(
            value = inputText,
            onValueChange = { inputText = it },
            textStyle = TextStyle(fontSize = 16.sp),
            modifier = Modifier
                .fillMaxWidth()
                .height(50.dp)
                .padding(8.dp)
                .border(1.dp, MaterialTheme.colorScheme.primary)
        )

        Text(
            text = if (speechText.isNotEmpty()) "You said: $speechText" else "No input yet.",
            style = TextStyle(fontSize = 16.sp)
        )

        Button(
            onClick = { launchSpeechRecognizer() },
            modifier = Modifier.fillMaxWidth()
        ) {
            Text("Start Speech to Text")
        }
    }
}
